<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'weLaunch' ) && ! class_exists( 'Redux' ) ) {
        return;
    }

    if( class_exists( 'weLaunch' ) ) {
        $framework = new weLaunch();
    } else {
        $framework = new Redux();
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "woocommerce_attribute_images_options";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */
            
    $attribute_taxonomy_names = wc_get_attribute_taxonomy_names();
    $attribute_taxonomy_names = array_combine($attribute_taxonomy_names, $attribute_taxonomy_names);

    $args = array(
        'opt_name' => 'woocommerce_attribute_images_options',
        'use_cdn' => TRUE,
        'dev_mode' => FALSE,
        'display_name' => esc_html__('WooCommerce Attribute Images', 'woocommerce-attribute-images'),
        'display_version' => '1.3.2',
        'page_title' => esc_html__('WooCommerce Attribute Images', 'woocommerce-attribute-images'),
        'update_notice' => TRUE,
        'intro_text' => '',
        'footer_text' => '&copy; '.date('Y').' weLaunch',
        'admin_bar' => false,
        'menu_type' => 'submenu',
        'menu_title' => esc_html__('Attribute Images', 'woocommerce-attribute-images'),
        'allow_sub_menu' => TRUE,
        'page_parent' => 'woocommerce',
        // 'page_parent_post_type' => 'stores',
        'customizer' => FALSE,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );


    global $weLaunchLicenses;
    if( (isset($weLaunchLicenses['woocommerce-attribute-images']) && !empty($weLaunchLicenses['woocommerce-attribute-images'])) || (isset($weLaunchLicenses['woocommerce-plugin-bundle']) && !empty($weLaunchLicenses['woocommerce-plugin-bundle'])) ) {
        $args['display_name'] = '<span class="dashicons dashicons-yes-alt" style="color: #9CCC65 !important;"></span> ' . $args['display_name'];
    } else {
        $args['display_name'] = '<span class="dashicons dashicons-dismiss" style="color: #EF5350 !important;"></span> ' . $args['display_name'];
    }

    $framework::setArgs( $opt_name, $args );
    /*
     *
     * ---> START SECTIONS
     *
     */

    $framework::setSection( $opt_name, array(
        'title'  => __('Attribute Images', 'woocommerce-attribute-images' ),
        'id'     => 'general',
        'desc'   => __('Need support? Please use the comment function on codecanyon.', 'woocommerce-attribute-images' ),
        'icon'   => 'el el-home',
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => __('General', 'woocommerce-attribute-images' ),
        'desc'       => __( 'To get auto updates please <a href="' . admin_url('tools.php?page=welaunch-framework') . '">register your License here</a>.', 'woocommerce-attribute-images' ),
        'id'         => 'general-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'enable',
                'type'     => 'switch',
                'title'    => __('Enable', 'woocommerce-attribute-images' ),
                'subtitle' => __('Enable Attribute Images.', 'woocommerce-attribute-images' ),
                'default'  => '1',
            ),
            array(
                'id'       => 'showTooltip',
                'type'     => 'checkbox',
                'title'    => __('Show Tooltip', 'woocommerce-attribute-images' ),
                'default'  => '0',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'showTextBelow',
                'type'     => 'checkbox',
                'title'    => __('Show Text Below image', 'woocommerce-attribute-images' ),
                'subtitle' => __('Show the attribute name below the attribute image.', 'woocommerce-attribute-images' ),
                'default'  => '0',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'performanceOnlyWooPages',
                'type'     => 'checkbox',
                'title'    => __('Performance: Scripts & Stylings', 'woocommerce-attribute-images' ),
                'subtitle' => __('Only execute CSS & JS Files on category & product pages.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'singleVariationsSupport',
                'type'     => 'checkbox',
                'title'    => __('Single Variations Support', 'woocommerce-attribute-images' ),
                'subtitle' => __('Show variation attribute images also for single variations in the shop loop. You need our <a href="https://www.welaunch.io/en/product/woocommerce-single-variations/" target="_blank">Single Variations plugin</a> for this.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'attributeTableEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Additional Information Table', 'woocommerce-attribute-images' ),
                'subtitle' => __('If image is set for an attribute the attribute value will be replaced with the attribute image style. This will be overwritten when our <a href="https://www.welaunch.io/en/product/woocommerce-group-attributes/" target="_blank">Group Attributes plugin</a> is enabled.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'variationsEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Variations Select', 'woocommerce-attribute-images' ),
                'subtitle' => __('If image is set for an attribute the variation selector will be replaced with images.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'attributeFilterWidgetEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Attribute Filter Widget', 'woocommerce-attribute-images' ),
                'subtitle' => __('Only works in List Mode. If image is set for an attribute the attribute value will be replaced with the attribute image in the layered navigation widget by attribute.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => __('Single Product Attribute Images', 'woocommerce-attribute-images' ),
        'id'         => 'single-product-attribute-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'singleProductAttributeImagesEnable',
                'type'     => 'switch',
                'title'    => __('Enable Single Product Attribute Images', 'woocommerce-attribute-images' ),
                'subtitle' => __('Will show Attribute attribute images on single product page.', 'woocommerce-attribute-images' ),
                'default'  => '0',
            ),
            array(
                'id'     =>'singleProductAttributeImagesImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '30',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('singleProductAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'   => 'singleProductAttributeImagesAttributes',
                'type' => 'select',
                'options' => $attribute_taxonomy_names,
                'multi' => true,
                'title' => __('Select Attributes', 'woocommerce-single-variations'), 
                'subtitle' => __('Which attributes should show when they have an image.', 'woocommerce-single-variations'),
                'required' => array('singleProductAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'       => 'singleProductAttributeImagesHook',
                'type'     => 'select',
                'title'    => __('Hook', 'woocommerce-attribute-images' ),
                'options'  => array(
                    'woocommerce_before_single_product' => __('Before Single Product', 'woocommerce-attribute-images'),
                    'woocommerce_before_single_product_summary' => __('Before Single Product Summary', 'woocommerce-attribute-images'),
                    'woocommerce_single_product_summary' => __('In Single Product Summary', 'woocommerce-attribute-images'),
                    'woocommerce_product_meta_start' => __('Before Meta Information', 'woocommerce-attribute-images'),
                    'woocommerce_product_meta_end' => __('After Meta Information', 'woocommerce-attribute-images'),
                    'woocommerce_after_single_product_summary' => __('After Single Product Summary', 'woocommerce-attribute-images'),
                    'woocommerce_after_single_product' => __('After Single Product', 'woocommerce-attribute-images'),
                    'woocommerce_after_main_content' => __('After Main Product', 'woocommerce-attribute-images'),
                    'woocommerce_before_add_to_cart_form' => __('Before add to Cart Form', 'woocommerce-attribute-images'),
                    'woocommerce_after_add_to_cart_form' => __('After add to Cart Form', 'woocommerce-attribute-images'),
                    
                ),
                'default' => 'woocommerce_single_product_summary',
                'required' => array('singleProductAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'     =>'singleProductAttributeImagesHookPosition',
                'type'     => 'spinner', 
                'title'    => __('Hook Position', 'woocommerce-attribute-images'),
                'default'  => '5',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('singleProductAttributeImagesEnable','equals','1'),
            ),  
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => __('Category Attribute Images', 'woocommerce-attribute-images' ),
        // 'desc'       => __('', 'woocommerce-attribute-images' ),
        'id'         => 'category-attribute-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'categoryAttributeImagesEnable',
                'type'     => 'switch',
                'title'    => __('Enable Category Attribute Images', 'woocommerce-attribute-images' ),
                'subtitle' => __('Will show Attribute attribute images in the shop loop.', 'woocommerce-attribute-images' ),
                'default'  => '1',
            ),
            array(
                'id'     =>'categoryAttributeImagesImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '30',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('categoryAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'   => 'categoryAttributeImagesAttributes',
                'type' => 'select',
                'options' => $attribute_taxonomy_names,
                'multi' => true,
                'title' => __('Select Attributes', 'woocommerce-single-variations'), 
                'subtitle' => __('Which attributes should show when they have an image in the loop.', 'woocommerce-single-variations'),
                'required' => array('categoryAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'       => 'categoryAttributeImagesHook',
                'type'     => 'select',
                'title'    => __('Hook', 'woocommerce-attribute-images' ),
                'options'  => array(
                    'woocommerce_before_shop_loop_item' => __('woocommerce_before_shop_loop_item', 'woocommerce-attribute-images'),
                    'woocommerce_before_shop_loop_item_title' => __('woocommerce_before_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_shop_loop_item_title' => __('woocommerce_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_after_shop_loop_item_title' => __('woocommerce_after_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_after_shop_loop_item' => __('woocommerce_after_shop_loop_item', 'woocommerce-attribute-images'),
                ),
                'default' => 'woocommerce_before_shop_loop_item_title',
                'required' => array('categoryAttributeImagesEnable','equals','1'),
            ),
            array(
                'id'     =>'categoryAttributeImagesHookPosition',
                'type'     => 'spinner', 
                'title'    => __('Hook Position', 'woocommerce-attribute-images'),
                'default'  => '20',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('categoryAttributeImagesEnable','equals','1'),
            ),  
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => __('Category Variation Swatches', 'woocommerce-attribute-images' ),
        // 'desc'       => __('', 'woocommerce-attribute-images' ),
        'id'         => 'category-variation-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'categoryVariationSwatchesEnable',
                'type'     => 'switch',
                'title'    => __('Enable Category Variation Swatches', 'woocommerce-attribute-images' ),
                'subtitle' => __('Will show variation attribute images in the shop loop.', 'woocommerce-attribute-images' ),
                'default'  => '1',
            ),
            array(
                'id'       => 'categoryVariationSwatchesHook',
                'type'     => 'select',
                'title'    => __('Hook', 'woocommerce-attribute-images' ),
                'options'  => array(
                    'woocommerce_before_shop_loop_item' => __('woocommerce_before_shop_loop_item', 'woocommerce-attribute-images'),
                    'woocommerce_before_shop_loop_item_title' => __('woocommerce_before_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_shop_loop_item_title' => __('woocommerce_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_after_shop_loop_item_title' => __('woocommerce_after_shop_loop_item_title', 'woocommerce-attribute-images'),
                    'woocommerce_after_shop_loop_item' => __('woocommerce_after_shop_loop_item', 'woocommerce-attribute-images'),
                ),
                'default' => 'woocommerce_before_shop_loop_item_title',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),
            array(
                'id'     =>'categoryVariationSwatchesHookPosition',
                'type'     => 'spinner', 
                'title'    => __('Hook Position', 'woocommerce-attribute-images'),
                'default'  => '20',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),   
            array(
                'id'     =>'categoryVariationSwatchesImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '30',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),
            array(
                'id'       => 'categoryVariationSwatchesImageSelector',
                'type'     => 'text',
                'title'    => __('Image Selector', 'woocommerce-attribute-images'),
                'subtitle' => __('For flatsome use: .attachment-woocommerce_thumbnail', 'woocommerce-attribute-images'),
                'default'  => '.woo-entry-image-main',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),
            array(
                'id'       => 'categoryVariationSwatchesPriceSelector',
                'type'     => 'text',
                'title'    => __('Price selector', 'woocommerce-attribute-images'),
                'default'  => '.price',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),
            array(
                'id'       => 'categoryVariationSwatchesLinkSelector',
                'type'     => 'text',
                'title'    => __('Link selector', 'woocommerce-attribute-images'),
                'subtitle' => __('For flatsome use: a (yes, just an "a")', 'woocommerce-attribute-images'),
                'default'  => '.woocommerce-LoopProduct-link',
                'required' => array('categoryVariationSwatchesEnable','equals','1'),
            ),
        )
    ) );


    $framework::setSection( $opt_name, array(
        'title'      => __('Styling', 'woocommerce-attribute-images' ),
        // 'desc'       => __('', 'woocommerce-attribute-images' ),
        'id'         => 'styling-settings',
        'subsection' => true,
        'fields'     => array(
            array(
               'id' => 'attribute-name-styling',
               'type' => 'section',
               'title' => __('Attribute Name Styling', 'woocommerce-attribute-images'),
               'subtitle' => __('Styling settings for the attribute name (e.g. color).', 'woocommerce-attribute-images'),
               'indent' => false 
            ),
            array(
                'id'       => 'attriNamebuteImageSize',
                'type'     => 'text',
                'title'    => __('Attribute Image Size', 'woocommerce-attribute-images'),
                'default'  => 'full',
            ),
            array(
                'id'     =>'attributeNameImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '100',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeNameImageBorderRadius',
                'type'     => 'spinner', 
                'title'    => __('Image Border Radius (%)', 'woocommerce-attribute-images'),
                'default'  => '0',
                'min'      => '0',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
               'id' => 'attribute-value-styling',
               'type' => 'section',
               'title' => __('Attribute Value Styling', 'woocommerce-attribute-images'),
               'subtitle' => __('Styling settings for the attribute value (e.g. erd).', 'woocommerce-attribute-images'),
               'indent' => false 
            ),
            array(
                'id'       => 'attributeImageSize',
                'type'     => 'text',
                'title'    => __('Attribute Image Size', 'woocommerce-attribute-images'),
                'default'  => 'thumbnail',
            ),
            array(
                'id'     =>'attributeImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '50',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeImageBorderRadius',
                'type'     => 'spinner', 
                'title'    => __('Image Border Radius (%)', 'woocommerce-attribute-images'),
                'default'  => '50',
                'min'      => '0',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeImageBorderColor',
                'type'  => 'color',
                'title' => __('Image Border Color', 'woocommerce-attribute-images'), 
                'validate' => 'color',
                'default' => '#f7f7f7',
            ),
            array(
                'id'     =>'attributeImageActiveBorderColor',
                'type'  => 'color',
                'title' => __('Image Active Border Color (Variations)', 'woocommerce-attribute-images'), 
                'validate' => 'color',
                'default' => '#FF9800',
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
